@@ -1921,39 +1921,26 @@ static PyObject* StartLoggingForPython(
     PyObject *keywordArgs)              // keyword arguments
 {
     unsigned long level, maxFiles, maxFileSize;
-    PyObject *encoding, *reuseObj, *rotateObj;
+    PyObject *encoding, *fileNameObj;
     ExceptionInfo exceptionInfo;
-    char *fileName, *prefix;
     int reuse, rotate;
+    char *prefix;
 
     maxFiles = 1;
     maxFileSize = DEFAULT_MAX_FILE_SIZE;
     prefix = DEFAULT_PREFIX;
-    reuseObj = rotateObj = NULL;
     encoding = NULL;
     reuse = rotate = 1;
-    if (!PyArg_ParseTupleAndKeywords(args, keywordArgs, "esl|llsOOO",
-            gStartLoggingWithFileKeywordList, Py_FileSystemDefaultEncoding,
-            &fileName, &level, &maxFiles, &maxFileSize, &prefix, &encoding,
-            &reuseObj, &rotateObj))
+    if (!PyArg_ParseTupleAndKeywords(args, keywordArgs, "O&l|llsOpp",
+            gStartLoggingWithFileKeywordList, PyUnicode_FSConverter,
+            &fileNameObj, &level, &maxFiles, &maxFileSize, &prefix, &encoding,
+            &reuse, &rotate))
         return NULL;
-    if (reuseObj) {
-        reuse = PyObject_IsTrue(reuseObj);
-        if (reuse < 0)
-            return NULL;
-    }
-    if (rotateObj) {
-        rotate = PyObject_IsTrue(rotateObj);
-        if (rotate < 0)
-            return NULL;
-    }
-    if (StartLoggingEx(fileName, level, maxFiles, maxFileSize, prefix,
-            reuse, rotate, &exceptionInfo) < 0) {
-        PyMem_Free(fileName);
+    if (StartLoggingEx(PyBytes_AS_STRING(fileNameObj), level, maxFiles,
+            maxFileSize, prefix, reuse, rotate, &exceptionInfo) < 0) {
         PyErr_SetString(PyExc_RuntimeError, exceptionInfo.message);
         return NULL;
     }
-    PyMem_Free(fileName);
     return SetEncodingHelper(encoding);
 }
 
@@ -2022,37 +2009,23 @@ static PyObject *StartLoggingForThreadForPython(
     PyObject *keywordArgs)              // keyword arguments
 {
     unsigned long level, maxFiles, maxFileSize;
-    PyObject *encoding, *reuseObj, *rotateObj;
-    char *fileName, *prefix;
+    PyObject *encoding, *fileNameObj;
     int reuse, rotate;
+    char *prefix;
 
     maxFiles = 1;
     maxFileSize = DEFAULT_MAX_FILE_SIZE;
     prefix = DEFAULT_PREFIX;
-    reuseObj = rotateObj = NULL;
     encoding = NULL;
     reuse = rotate = 1;
-    if (!PyArg_ParseTupleAndKeywords(args, keywordArgs, "esl|llsOOO",
-            gStartLoggingWithFileKeywordList, Py_FileSystemDefaultEncoding,
-            &fileName, &level, &maxFiles, &maxFileSize, &prefix, &encoding,
-            &reuseObj, &rotateObj))
+    if (!PyArg_ParseTupleAndKeywords(args, keywordArgs, "O&l|llsOpp",
+            gStartLoggingWithFileKeywordList, PyUnicode_FSConverter,
+            &fileNameObj, &level, &maxFiles, &maxFileSize, &prefix, &encoding,
+            &reuse, &rotate))
         return NULL;
-    if (reuseObj) {
-        reuse = PyObject_IsTrue(reuseObj);
-        if (reuse < 0)
-            return NULL;
-    }
-    if (rotateObj) {
-        rotate = PyObject_IsTrue(rotateObj);
-        if (rotate < 0)
-            return NULL;
-    }
-    if (StartLoggingForPythonThreadEx(fileName, level, maxFiles, maxFileSize,
-            prefix, reuse, rotate) < 0) {
-        PyMem_Free(fileName);
+    if (StartLoggingForPythonThreadEx(PyBytes_AS_STRING(fileNameObj), level,
+            maxFiles, maxFileSize, prefix, reuse, rotate) < 0)
         return NULL;
-    }
-    PyMem_Free(fileName);
     return SetEncodingHelper(encoding);
 }
 
@@ -2165,15 +2138,11 @@ static PyObject* GetLoggingFileNameForPython(
 
     loggingState = GetLoggingState();
     if (loggingState)
-        return PyUnicode_Decode(loggingState->state->fileName,
-                strlen(loggingState->state->fileName),
-                Py_FileSystemDefaultEncoding, NULL);
+        return PyUnicode_DecodeFSDefault(loggingState->state->fileName);
     ACQUIRE_LOCK(gLoggingStateLock);
-    if (gLoggingState)
-        fileNameObj = PyUnicode_Decode(gLoggingState->fileName,
-                strlen(gLoggingState->fileName), Py_FileSystemDefaultEncoding,
-                NULL);
-    else {
+    if (gLoggingState) {
+        fileNameObj = PyUnicode_DecodeFSDefault(gLoggingState->fileName);
+    } else {
         Py_INCREF(Py_None);
         fileNameObj = Py_None;
     }
@@ -2491,6 +2460,9 @@ static PyObject *Module_Initialize(void)
         return NULL;
 
     // add version and build time for easier support
+    if (PyModule_AddStringConstant(module, "__version__",
+            BUILD_VERSION_STRING) < 0)
+        return NULL;
     if (PyModule_AddStringConstant(module, "version",
             BUILD_VERSION_STRING) < 0)
         return NULL;
@@ -2713,4 +2685,3 @@ void __attribute__ ((destructor)) Finalize(void)
     StopLogging();
 }
 #endif
-
